==> ZenTaoPMS.17.2.php7.1.zip: zentaopms/extension/max/researchplan/lang/zh-tw.php <==
<?php
$lang->researchplan->browse = '瀏覽列表';
$lang->researchplan->create = '創建調研計劃';
$lang->researchplan->edit   = '編輯調研計劃';
$lang->researchplan->view   = '調研計劃詳情';
$lang->researchplan->delete = '刪除調研計劃';
$lang->researchplan->common = '調研計劃';

$lang->researchplan->basicInfo   = '基本信息';
$lang->researchplan->lifeTime    = '調研計劃的一生';
$lang->researchplan->id          = 'ID';
$lang->researchplan->name        = '計劃名稱';
$lang->researchplan->customer    = '客戶';
$lang->researchplan->stakeholder = '干係人';
$lang->researchplan->objective   = '目的';
$lang->researchplan->begin       = '開始時間';
$lang->researchplan->end         = '結束時間';
$lang->researchplan->location    = '地點';
$lang->researchplan->team        = '我方參加人員';
$lang->researchplan->method      = '方式';
$lang->researchplan->outline     = '調研大綱';
$lang->researchplan->schedule    = '日程安排';
$lang->researchplan->createdBy   = '由誰創建';
$lang->researchplan->createdDate = '創建時間';
$lang->researchplan->editedBy    = '由誰編輯';
$lang->researchplan->editedDate  = '最後編輯';

$lang->researchplan->confirmDelete = '確認刪除該條調研計劃？';
$lang->researchplan->deleted       = '已刪除';

$lang->researchplan->labelList = array();
$lang->researchplan->labelList['all'] = '所有';

$lang->researchplan->methodList = array();
$lang->researchplan->methodList[''] = '';
$lang->researchplan->methodList['videoConference']    = '視頻會議';
$lang->researchplan->methodList['interview']          = '面談';
$lang->researchplan->methodList['questionnaire']      = '調查問卷';
$lang->researchplan->methodList['telephoneInterview'] = '電話訪談';

==> ZenTaoPMS-21.0-php7.1.zip: zentaopms/extension/max/researchplan/lang/zh-tw.php <==
<?php
$lang->researchplan->browse = '調研計劃列表';
$lang->researchplan->create = '創建調研計劃';
$lang->researchplan->edit   = '編輯調研計劃';
$lang->researchplan->view   = '調研計劃詳情';
$lang->researchplan->delete = '刪除調研計劃';
$lang->researchplan->common = '調研計劃';

$lang->researchplan->basicInfo   = '基本信息';
$lang->researchplan->lifeTime    = '調研計劃的一生';
$lang->researchplan->id          = 'ID';
$lang->researchplan->name        = '計劃名稱';
$lang->researchplan->customer    = '客戶';
$lang->researchplan->stakeholder = '干係人';
$lang->researchplan->objective   = '目的';
$lang->researchplan->begin       = '開始時間';
$lang->researchplan->end         = '結束時間';
$lang->researchplan->location    = '地點';
$lang->researchplan->team        = '我方參加人員';
$lang->researchplan->method      = '方式';
$lang->researchplan->outline     = '調研大綱';
$lang->researchplan->schedule    = '日程安排';
$lang->researchplan->createdBy   = '由誰創建';
$lang->researchplan->createdDate = '創建時間';
$lang->researchplan->editedBy    = '由誰編輯';
$lang->researchplan->editedDate  = '最後編輯';

$lang->researchplan->confirmDelete = '確認刪除該條調研計劃？';
$lang->researchplan->deleted       = '已刪除';

$lang->researchplan->featureBar['browse'] = array();
$lang->researchplan->featureBar['browse']['all'] = '全部';

$lang->researchplan->methodList = array();
$lang->researchplan->methodList[''] = '';
$lang->researchplan->methodList['videoConference']    = '視頻會議';
$lang->researchplan->methodList['interview']          = '面談';
$lang->researchplan->methodList['questionnaire']      = '調查問卷';
$lang->researchplan->methodList['telephoneInterview'] = '電話訪談';
